import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import { field, createComponentMemo } from '../prop-types';
import MoleculeCheckboxField from '@s-ui/react-molecule-checkbox-field';
import IconCheck from '../Icons/IconCheck';

var Checkbox = function Checkbox(_ref) {
  var checkbox = _ref.checkbox,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[checkbox.id];
  var alertMessages = alerts[checkbox.id];
  var checked = 'false';

  try {
    checked = JSON.parse(checkbox.value);
  } catch (e) {
    console.error('Impossible to convert to json checkbox value', checkbox);
  }

  var onChangeCallback = function onChangeCallback(e) {
    return onChange(checkbox.id, JSON.stringify(e.target.checked));
  };

  var onBlurCallback = function onBlurCallback() {
    return onBlur(checkbox.id);
  }; // transform constraints to props


  var constraints = checkbox.constraints || [];
  var checkboxProps;
  checkboxProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property;

    return _extends({}, acc, (constraint == null ? void 0 : (_constraint$property = constraint.property) == null ? void 0 : _constraint$property.notnull) === '' && {
      required: true
    });
  }, checkboxProps);
  checkboxProps = _extends({}, checkboxProps, {
    id: checkbox.id,
    label: checkbox.label,
    value: checked,
    checked: checked,
    checkedIcon: IconCheck,
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    tabIndex: tabIndex,
    intermediate: false
  }, checkbox.disabled && {
    disabled: true
  }, checkbox.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (checkboxProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: checkbox.id,
    innerProps: checkboxProps
  }); // render custom component

  if ( /*#__PURE__*/React.isValidElement(rendererResponse)) {
    return rendererResponse;
  } // render SUI component


  return /*#__PURE__*/React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Switch sui-FormBuilder-" + (checkboxProps.id || tabIndex)
  }, /*#__PURE__*/React.createElement(MoleculeCheckboxField, Object.assign({}, checkboxProps, rendererResponse)));
};

Checkbox.displayName = 'Switch';
export default /*#__PURE__*/React.memo(Checkbox, createComponentMemo('checkbox'));