import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import { field, createComponentMemo } from '../prop-types';
import MoleculeRadioButtonGroup from '@s-ui/react-molecule-radio-button-group';
import MoleculeRadioButtonField from '@s-ui/react-molecule-radio-button-field';

var Radio = function Radio(_ref) {
  var radio = _ref.radio,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[radio.id];
  var alertMessages = alerts[radio.id];
  var datalist = radio.datalist;

  var onChangeHandler = function onChangeHandler(value) {
    return onChange(radio.id, value);
  };

  var radioProps = _extends({
    id: radio.id,
    label: radio.label,
    tabIndex: tabIndex
  }, radio.disabled && {
    disabled: true
  }, radio.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (radioProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: radio.id,
    innerProps: _extends({}, radioProps, {
      datalist: datalist
    })
  }); // render custom component

  if ( /*#__PURE__*/React.isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Radio sui-FormBuilder-" + (radioProps.id || tabIndex)
  }, radio.label && /*#__PURE__*/React.createElement("label", {
    className: "sui-FormBuilder-Radio-label"
  }, radio.label), /*#__PURE__*/React.createElement(MoleculeRadioButtonGroup, Object.assign({
    onChange: function onChange(_, _ref2) {
      var value = _ref2.value;
      onChangeHandler(value);
    },
    id: radio.id,
    value: radio.value
  }, rendererResponse), datalist.map(function (button) {
    return /*#__PURE__*/React.createElement(MoleculeRadioButtonField, {
      id: button.value,
      key: button.value,
      value: button.value,
      label: button.text,
      helpText: button.hint
    });
  })));
};

Radio.displayName = 'Radio';
export default /*#__PURE__*/React.memo(Radio, createComponentMemo('radio'));